---
name: "\U0001F680 Feature request"
about: Suggest an idea for Merlin
title: "[FEAT] "
labels: enhancement
assignees: ''

---

<!-- NOTE: If your feature is related to a bug, please file a Bug report instead! -->

## 🚀 Feature Request

**What problem is this feature looking to solve?**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Additional context**
Add any other context or screenshots about the feature request here.
